@@ -87,7 +87,7 @@ class Hand(object):
         self._cards = self._set_cards(cards)
 
     def _set_cards(self, cards):
-        """Return the hand's card as a list of Card objects."""
+        """Return the hand's cards as a list of Card objects."""
         card_list = []
         if cards:
             if isinstance(cards, str):
@@ -288,6 +288,9 @@ class Hand(object):
     def shape(self):
         """Return the shape of the hand as a list in descending
            order by holding e.g. [4, 3, 3, 3]."""
+        if len(self._shape) != 4:
+            self._get_suit_lengths()
+            self._shape = self._get_shape()
         return self._shape
 
     @property
